Learn R Programming

eventTrack (version 1.0.4)

piecewiseExp_profile_loglik_tau: Profile maximum log-likelihood function for change points in piecewise Exponential survival model

Description

In a piecewise Exponential survival model, the estimates for the value of the hazard function can be given explicitly, see Fang and Su (2011), and can be computed using lambda_j_Exp. The values of the change points can then be computed using the profile log-likelihood function. The function piecewiseExp_profile_loglik_tau computes the value of this profile log-likelihood function and can be used together with optim to compute the change points \(\tau_1, \ldots, \tau_{k}\).

Usage

piecewiseExp_profile_loglik_tau(tau, time, event)

Value

Value of the profile likelihood function.

Arguments

tau

Single number or vector with values of change points.

time

Event times, censored or observed, in months.

event

Censoring indicator, 1 for event, 0 for censored.

Author

Kaspar Rufibach (maintainer)
kaspar.rufibach@roche.com

References

Fang, L., Zheng, S. (2011). A hybrid approach to predicting events in clinical trials with time-to-event outcomes. Contemp. Clin. Trials, 32, 755--759.

Goodman, M.S., Li, Y., Tiwari, R.C. (2011). Detecting multiple change points in piecewise constant hazard functions. J. Appl. Stat, 38(11), 2523--2532.